@@ -119,11 +119,11 @@ for app in get_apps():
 
         smok_dirs.append(path)
 
-        for index, smok_dir in enumerate(smok_dirs):
+        for smok_dir in smok_dirs:
 
             test_name = u'{0}_{1}'.format(
                 app.__package__.replace('.', '_').upper(),
-                index).encode('utf-8')
+                smok_dir).encode('utf-8')
             
             attrs = {
                 'fixtures': [],
